@@ -48,6 +48,11 @@ main (gint argc, gchar **argv)
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
+#ifdef HAVE_GCONF
+  /* GConf uses ORBit2 which need GThread. See bug #565516 */
+  g_thread_init (NULL);
+#endif
+
   if (!gtk_init_with_args (&argc, &argv, "", goptions, GETTEXT_PACKAGE, &error))
     {
       g_printerr ("%s\n", error->message);
